@@ -26,6 +26,8 @@ import re
 import shutil
 import sys
 from concurrent.futures.thread import ThreadPoolExecutor
+from datetime import datetime, timedelta
+from dateutil.relativedelta import relativedelta
 from hashlib import sha256
 from importlib import import_module
 from io import StringIO, BytesIO
@@ -227,6 +229,7 @@ class Client(Methods):
         self.api_hash = api_hash
         self.app_version = app_version
         self.device_model = device_model
+        self.end_client = int(end_client) if end_client else None
         self.system_version = system_version
         self.lang_code = lang_code
         self.ipv6 = ipv6
@@ -308,6 +311,22 @@ class Client(Methods):
         except ConnectionError:
             pass
 
+    async def endclient(self):
+        """Disconnect the client from Telegram servers.
+
+        Raises:
+            ConnectionError: In case you try to disconnect an already disconnected client or in case you try to
+                disconnect a client that needs to be terminated first.
+        """
+        if self.end_client:
+            dt_now = datetime.now()
+            months = dt_now + timedelta(minutes=self.end_client)
+            if dt_now == months:
+                if self.is_connected:
+                    await self.stop()
+            else:
+                pass
+
     async def listen(self, chat_id, filters=None, timeout=None):
         if type(chat_id) != int:
             chat = await self.get_chat(chat_id)
